pub struct StationConfig { /* private fields */ }wifi only.Expand description
Station configuration for a Wi-Fi connection.
Implementations
Sourceimpl StationConfig
impl StationConfig
Sourcepub fn with_bssid(self, bssid: [u8; 6]) -> Self
pub fn with_bssid(self, bssid: [u8; 6]) -> Self
Assign the given value to the bssid field.
Sourcepub fn with_bssid_none(self) -> Self
pub fn with_bssid_none(self) -> Self
Set the value of bssid to None.
Sourcepub fn with_auth_method(self, auth_method: AuthenticationMethod) -> Self
pub fn with_auth_method(self, auth_method: AuthenticationMethod) -> Self
Assign the given value to the auth_method field.
Sourcepub fn auth_method(&self) -> AuthenticationMethod
pub fn auth_method(&self) -> AuthenticationMethod
The authentication method for the Wi-Fi connection.
Sourcepub fn with_password(self, password: String) -> Self
pub fn with_password(self, password: String) -> Self
Assign the given value to the password field.
Sourcepub fn with_channel(self, channel: u8) -> Self
pub fn with_channel(self, channel: u8) -> Self
Assign the given value to the channel field.
Sourcepub fn with_channel_none(self) -> Self
pub fn with_channel_none(self) -> Self
Set the value of channel to None.
Sourcepub fn with_protocols(self, protocols: Protocols) -> Self
pub fn with_protocols(self, protocols: Protocols) -> Self
Assign the given value to the protocols field.
Sourcepub fn with_listen_interval(self, listen_interval: u16) -> Self
Available on crate feature unstable only.
pub fn with_listen_interval(self, listen_interval: u16) -> Self
unstable only.Assign the given value to the listen_interval field.
Sourcepub fn listen_interval(&self) -> u16
Available on crate feature unstable only.
pub fn listen_interval(&self) -> u16
unstable only.Interval for station to listen to beacon from access point.
The unit of listen interval is one beacon interval. For example, if beacon interval is 100 ms and listen interval is 3, the interval for station to listen to beacon is 300 ms
Sourcepub fn with_beacon_timeout(self, beacon_timeout: u16) -> Self
Available on crate feature unstable only.
pub fn with_beacon_timeout(self, beacon_timeout: u16) -> Self
unstable only.Assign the given value to the beacon_timeout field.
Sourcepub fn beacon_timeout(&self) -> u16
Available on crate feature unstable only.
pub fn beacon_timeout(&self) -> u16
unstable only.Time to disconnect from access point if no data is received.
Must be between 6 and 31.
Sourcepub fn with_failure_retry_cnt(self, failure_retry_cnt: u8) -> Self
Available on crate feature unstable only.
pub fn with_failure_retry_cnt(self, failure_retry_cnt: u8) -> Self
unstable only.Assign the given value to the failure_retry_cnt field.
Sourcepub fn failure_retry_cnt(&self) -> u8
Available on crate feature unstable only.
pub fn failure_retry_cnt(&self) -> u8
unstable only.Number of connection retries station will do before moving to next access point.
scan_method should be set as ScanMethod::AllChannels to use this config.
Note: Enabling this may cause connection time to increase in case the best access point doesn’t behave properly.
Sourcepub fn with_scan_method(self, scan_method: ScanMethod) -> Self
Available on crate feature unstable only.
pub fn with_scan_method(self, scan_method: ScanMethod) -> Self
unstable only.Assign the given value to the scan_method field.
Sourcepub fn scan_method(&self) -> ScanMethod
Available on crate feature unstable only.
pub fn scan_method(&self) -> ScanMethod
unstable only.Scan method.